"use strict";
const path     = require('path')
const inquirer = require('inquirer')
const origin   = require('git-origin-url')
const jsonfile = require('jsonfile')
const gd       = require('../helper/gd.js')
const support  = require('../helper/support.js')
const request  = require('request')
const sudo     = require('sudo-prompt')
const isThere  = require('is-there')
const gd_theme = require('./gd-theme.js')

module.exports = function() {

  const conf = gd.conf()

  var pkg = conf.package_file;

  var new_conf = JSON.parse(JSON.stringify(conf)); // *dirty* deep-clone object

  delete new_conf.package_file;
  delete new_conf.theme;
  delete new_conf.site_local;
  delete new_conf.site_root;

  if(new_conf['context']) delete new_conf.context;

  origin(function (err, git) {
    if(err) {
      gd.error("This project Git repository doesn't seem to be properly initialized.\n");
      // output stack
      console.log(err);
      exit();
    }



    var name = path.basename(git).replace('.git', '');

    new_conf.name = name;
    new_conf.repository.url = git;

    request({
      url: 'http://git.studio.gd/api/v3/projects?per_page=250&order_by=id&sort=desc',
      headers: {
        'PRIVATE-TOKEN': conf.repository.token
      }
    }, function (error, response, data) {
      if (!error && response.statusCode == 200) {

        var projects = JSON.parse(data);
        // console.log(JSON.stringify(projects, null, 2))

        for(var p in projects) {
          if(projects[p].ssh_url_to_repo === git) {
            new_conf.config.gitlab_id = projects[p].id;
            break;
          }
        }

      }
      conf_step2(conf, pkg, new_conf);
    })

  }); // origin (git)


  function conf_step2(conf, pkg, new_conf) {


    /* AUTODETECT */
    let default_type    = 'Drupal';
    let default_version = '7.x';

    if(isThere(conf.site_local + '/autoload.php')
    && isThere(conf.site_local + '/update.php')
    && isThere(conf.site_local + '/web.config')){
      default_version = '8.x';
    }
    else if(isThere(conf.site_local + '/app.php')
    && isThere(conf.site_local + '/config.php')
    && isThere(conf.site_local + '/web.config')){
      default_type = 'Symfony';
      default_version = '3';
    }
    else if(isThere(conf.site_local + '/wp-config.php')){
      default_type = 'Wordpress';
      default_version = '4';
    }
    /* AUTODETECT END */



    var choices = [];
    for (var T in support.type) {
      if(T === 'default') continue;
      choices.push(T[0].toUpperCase() + T.slice(1))
    }

    inquirer.prompt(
    [
      {
        type: "list",
        name: "type",
        message: "Type",
        choices,
        default: function() { return default_type }
      }
    ]).then(function(answers) {
      // console.log( JSON.stringify(answers, null, "  ") );

      new_conf.config.type = answers.type.toLowerCase();

      var version_input_type = 'list';

      if(new_conf.config.type === 'drupal') {
        var choices = ['8.x', '7.x'];
      }
      else {
        version_input_type = 'input';
      }

      inquirer.prompt(
      [
        {
          type: version_input_type,
          name: "version",
          message: "Version",
          choices,
          default: function() { return default_version }
        },
        {
          type: 'input',
          name: "shortname",
          message: "Project shortname",
          default: function() { return new_conf.name }
        },
        {
          type: 'input',
          name: "theme_folder",
          message: "Theme's folder name",
          default: function(a) { return a.shortname + '_theme' }
        },
        {
          type: 'input',
          name: "domain",
          message: "Nom de domaine",
          default: function(a) { return a.shortname + '.com' }
        }
      ]).then(function(answers) {
        //console.log( JSON.stringify(answers, null, "  ") );

        new_conf.config.version = answers.version;
        new_conf.shortname      = answers.shortname;
        new_conf.config.db_name = new_conf.shortname;

        var theme_folder = answers.theme_folder;
        var webdir_path  = 'web/';

        let wp_content = '';
        if(new_conf.config.type === 'wordpress'){
          wp_content = new_conf.config['wp-content'] + '/';
        }

        if(answers.domain) {
          new_conf.servers.dev.url = 'dev.' + answers.domain;
          new_conf.servers.preprod.url = new_conf.shortname + '.preprod.it';
          new_conf.servers.prod.url = answers.domain;
        }

        new_conf.servers.preprod.site = '/home/preprod/' + new_conf.name + '/' + webdir_path;
        new_conf.servers.prod.site = '/home/prod/' + new_conf.name + '/' + webdir_path;

        if(new_conf.config.type === 'wordpress' || new_conf.config.version !== '7.x') {
          new_conf.servers.preprod.theme = '/home/preprod/' + new_conf.name + '/' + webdir_path + wp_content + 'themes/' + theme_folder;
          new_conf.servers.prod.theme = '/home/prod/' + new_conf.name + '/' + webdir_path + wp_content + 'themes/' + theme_folder;
        }
        else {
          new_conf.servers.preprod.theme = '/home/preprod/' + new_conf.name + '/' + webdir_path + '/sites/all/themes/' + theme_folder;
          new_conf.servers.prod.theme = '/home/prod/' + new_conf.name + '/' + webdir_path + '/sites/all/themes/' + theme_folder;
        }

        try {
          jsonfile.writeFileSync(pkg, new_conf, {spaces: 2});
        } catch(e) {
          sudo.exec('chmod 0777 ' + conf.theme + '/package.json', {}, function() {
            jsonfile.writeFileSync(pkg, new_conf, {spaces: 2});
          });
        }

        gd.log('\n\nrepository.url : ');
        console.log(new_conf.repository.url + '\n');

        gd.log('gitlab id : ');
        console.log(new_conf.config.gitlab_id + '\n');

        gd.log('name / shortname: ');
        console.log(new_conf.name + ' / ' + new_conf.shortname + '\n');

        gd.log('config.type / config.version : ');
        console.log(new_conf.config.type + ' / ' + new_conf.config.version + '\n');

        gd.log('config.db_name : ');
        console.log(new_conf.config.db_name + '\n');

        gd.log('servers.preprod.site : ');
        console.log(new_conf.servers.preprod.site + '\n');
        gd.log('servers.preprod.theme : ');
        console.log(new_conf.servers.preprod.theme + '\n');

        gd.log('servers.prod.site : ');
        console.log(new_conf.servers.prod.site + '\n');
        gd.log('servers.prod.theme : ');
        console.log(new_conf.servers.prod.theme + '\n');

        gd.log('package.json updated !' + '\n');


        // execute gd-theme command
        gd_theme(theme_folder);

      });
    });
  }


};
