"use strict";
const gd       = require('../helper/gd.js')
const fs       = require('fs')
const jsonfile = require('jsonfile')
const sudo     = require('sudo-prompt')

module.exports = function(server, plugin, cb) {

  const conf = gd.conf()

  var plugins = require('../config/plugin.json');

  if(plugin && !plugins[plugin]) {
    gd.error(`Plugin "${plugin}" does not exist.\n`);
  }
  if(!plugin || !plugins[plugin]) {

    if(!conf['plugins'] || (conf['plugins'] && !conf['plugins'][0])) {
      gd.error('No plugin to remove.\n');
      return;
    }

    var inquirer = require('inquirer');

    var choices = [];

    for(var p in conf.plugins) {
      choices.push(conf.plugins[p])
    }

    inquirer.prompt(
    [
      {
        type: "list",
        name: "Plugin",
        message: "Select a plugin to remove",
        paginated : true,
        choices
      }
    ])
    .then(function (answers) {
      // console.log( JSON.stringify(answers, null, "  ") );
      /*for(var a in answers.Plugin) {
        remove_plugin(conf, server, cb, answers.Plugin[a], plugins);
      }*/
      remove_plugin(conf, server, cb, answers.Plugin, plugins);
    });
  }
  else {
    remove_plugin(conf, server, cb, plugin, plugins);
  }

};


function remove_plugin(conf, server, cb, plugin, plugins) {
  gd.log('REMOVE PLUGIN ' + plugin);

  const bower     = plugins[plugin]['bower'];
  const bower_tpl = plugins[plugin]['bower-template'];

  let new_conf = JSON.parse(JSON.stringify(conf)); // dirty-clone object
  delete new_conf.package_file;
  delete new_conf.theme;
  delete new_conf.site_local;
  delete new_conf.site_root;

  let i = new_conf.plugins.indexOf(plugin)

  new_conf.plugins.splice(i, 1);

  let cmd = 'cd ' + conf.theme;

  if(bower) {
    cmd+= ' && ';
    cmd+= 'bower uninstall -S ' + bower;
  }


  if(bower_tpl['js'] || bower_tpl['css']) {

    if(bower_tpl['js']){
      for (let js in bower_tpl['js']) {
        cmd+= ' && rm ' + conf.theme + '/src/js/plugin/' + bower_tpl['js'][js];
      }
    }
    if(bower_tpl['css']){
      for (let css in bower_tpl['css']) {
        cmd+= ' && rm ' + conf.theme + '/src/css/plugin/' + bower_tpl['css'][css];
      }
    }
  }



  gd.exec(cmd, cb);

  try {
    jsonfile.writeFileSync(conf.package_file, new_conf, {spaces: 2});
  } catch(e) {
    sudo.exec('chmod 0777 ' + conf.theme + '/package.json', {}, function() {
      jsonfile.writeFileSync(conf.package_file, new_conf, {spaces: 2});
    })
  }

}
