"use strict";
const gd       = require('../helper/gd')
const jsonfile = require('jsonfile')
const sudo     = require('sudo-prompt')
const sortObj  = require('sort-object')
const path     = require('path')

module.exports = function(server, plugin, cb) {

  const conf = gd.conf()

  let plugins = require('../config/plugin.json');

  if(plugin && !plugins[plugin]) {
    gd.error(`Plugin "${plugin}" does not exist.\n`);
  }
  if(!plugin || !plugins[plugin]) {

    var inquirer = require('inquirer');

    var choices = [];

    // dont display plugins already installed
    if(conf['plugins'] && conf['plugins'][0]) {
      for(var p in conf.plugins) {
        delete plugins[conf.plugins[p]];
      }
    }
    // hide drupal.js plugin for drupal project
    if(conf.config.type === 'drupal'){
      delete plugins['drupal.js'];
    }
    
    plugins = sortObj(plugins);

    for(var p in plugins) {
      choices.push(p)
    }

    inquirer.prompt(
    [
      {
        type: "list",
        name: "Plugin",
        message: "Select a plugin to install",
        paginated : true,
        choices
      }
    ])
    .then(function (answers) {
      // console.log( JSON.stringify(answers, null, "  ") );
      /*for(var a in answers.Plugin) {
        install_plugin(conf, cb, answers.Plugin[a], plugins);
      }*/
      install_plugin(conf, cb, answers.Plugin, plugins);
    });
  }
  else {
    install_plugin(conf, cb, plugin, plugins);
  }
};


function install_plugin(conf, cb, plugin, plugins) {
  gd.log('INSTALL PLUGIN ' + plugin);

  const bower     = plugins[plugin]['bower'];
  const bower_tpl = plugins[plugin]['bower-template'];
  const script    = plugins[plugin]['script'];

  const bower_tpl_path = path.resolve(__dirname + '/../files/bower-template');

  let new_conf = JSON.parse(JSON.stringify(conf)); // dirty-clone object
  delete new_conf.package_file;
  delete new_conf.theme;
  delete new_conf.site_local;
  delete new_conf.site_root;

  if(!new_conf['plugins']) {
    new_conf.plugins = [];
  }

  if(new_conf.plugins.indexOf(plugin) < 0){ // add plugin to package.json only if it's not already
    new_conf.plugins.push(plugin);
  }

  let cmd = 'cd ' + conf.theme;

  if(bower) {
    cmd+= ' && ';
    cmd+= 'bower i -S ' + bower;
  }


  if(bower_tpl['js'] || bower_tpl['css']) {

    if(bower_tpl['js']){
      for (let js in bower_tpl['js']) {
        cmd+= ' && cp ' + bower_tpl_path + '/js/' + bower_tpl['js'][js] + ' ' + conf.theme + '/src/js/plugin/' + bower_tpl['js'][js];
      }
    }
    if(bower_tpl['css']){
      for (let css in bower_tpl['css']) {
        cmd+= ' && cp ' + bower_tpl_path + '/css/' + bower_tpl['css'][css] + ' ' + conf.theme + '/src/css/plugin/' + bower_tpl['css'][css];
      }
    }

  }

  if(script) {
    cmd+= ' && ' + script;
  }

  gd.exec(cmd, cb);

  try{
    jsonfile.writeFileSync(conf.package_file, new_conf, {spaces: 2});
  }catch(e){
    sudo.exec('chmod 0777 ' + conf.theme + '/package.json', {}, function() {
      jsonfile.writeFileSync(conf.package_file, new_conf, {spaces: 2});
    });
  }


};
