"use strict";
const fs         = require('fs')
const gd         = require('../helper/gd')
const support    = require('../helper/support')
const bashEscape = require('../helper/bash-escape')
const userHome   = require('user-home')
const isThere    = require('is-there')

module.exports = function(server, cb) {

  const conf        = gd.conf()
  const conf_global = gd.globalConf()
  const type        = conf.config.type
  const version     = conf.config.version

  server = gd.server(server);

  if(support.isCommandExcluded('settings', true)) {
    cb ? cb() : gd.autoClose()
    return;
  }

  let cmd       = '';
  let src       = '';
  let src_path  = '';
  let dest      = '';
  const C = conf.servers[server];
  const db_name = gd.db(server);
  const db_user = conf_global.get('db_user');
  const db_pass = conf_global.get('db_pass');



  // LOAD TEMPLATE SETTINGS
  let tpl_path = __dirname + '/../files/settings/' + type

  if(type === 'drupal'){
    tpl_path+= '-' + version
  }

  let tpl = fs.readFileSync(tpl_path, 'utf8');




  // SETTINGS FILE SOURCE
  src = server === 'dev' ? conf.site_local : C.site;

  if(type === 'drupal'){
    src_path = '/sites/default/default.settings.php'
  }
  else if(type === 'wordpress'){

    src_path = '/wp-config-gd.php'
    if(!isThere(conf.site_local + src_path)){
      src_path = '/wp-config-sample.php'
    }
  }

  src+= src_path;



  let src_content = fs.readFileSync(conf.site_local + src_path, 'utf8');



  // REPLACE CONTENT IN SRC
  if(type === 'wordpress'){

    src_content = src_content.replace('votre_nom_de_bdd', db_name);
    src_content = src_content.replace('database_name_here', db_name);
    src_content = src_content.replace('votre_utilisateur_de_bdd', db_user);
    src_content = src_content.replace('username_here', db_user);
    src_content = src_content.replace('votre_mdp_de_bdd', db_pass);
    src_content = src_content.replace('password_here', db_pass);
    src_content = src_content.replace("define('DB_CHARSET', 'utf8');", "define('DB_CHARSET', 'utf8mb4');");
    src_content = src_content.replace("<?php", "<?php \n\ndefine('WP_CONTENT_DIR', dirname(__FILE__) . '/app');\ndefine('WP_CONTENT_URL', 'http://" + gd.dev_url() + "/app' );");

    if(server === 'dev'){
      src_content = src_content.replace("define('WP_DEBUG', false);", "define('WP_DEBUG', true);");
    }
  }



  // REPLACE PLACEHOLDER IN TEMPLATE
  tpl = tpl.replace(/__DB_NAME__/, db_name);
  tpl = tpl.replace(/__DB_USER__/, db_user);
  tpl = tpl.replace(/__DB_PASSWORD__/, db_pass);



  // SETTINGS FILE DESTINATION
  if(type === 'drupal'){
    dest = src.replace('default.settings.php', 'settings.php');
  }
  else if(type === 'wordpress'){
    dest = src.replace('wp-config-sample.php', 'wp-config.php');
    dest = dest.replace('wp-config-gd.php', 'wp-config.php');
  }


  if(server === 'dev'){

    if(require('is-there')(dest)){
      gd.log(`The file ${dest} already exist.`);
      gd.status(`You must edit it manually.`);
      return;
    }

    fs.writeFile(dest, src_content + tpl.replace("\\$",'$'), (err) => {

      if(err) gd.exit(err);

      gd.status(`File ${dest} created.`);

      if(cb) cb()
    });
    return;///////
  }
  else{ // remote server

    const S = C.user + '@' + C.ip;

    gd.log('CREATE ' + dest + ' (if not exist) on ' + server + ' ' + S);

    cmd+= `ssh -T -p ${C.port} ${S} `;

    cmd+= '"';
    cmd+= 'test -e ' + dest;
    cmd+= ' || (';
    cmd+= 'cp ' + src + ' ' + dest;
    cmd+= ' && ';

    if(type === 'drupal'){
      cmd+= 'echo ' + bashEscape(tpl) + ' >>  ' + dest;
    }
    else if(type === 'wordpress'){
      cmd+= 'echo ' + bashEscape(src_content.replace("$","\\$") + tpl) + ' >  ' + dest;
    }

    cmd+= ')"';
  }

  const message = '';

  gd.throbber.start();

  gd.exec(cmd, cb, message);
};
