const gd         = require('./helper/gd')
const cmd_pull   = require('./command/pull')
const cmd_gulp   = require('./command/gulp')
const cmd_asset  = require('./command/asset')
const cmd_cc     = require('./command/clear-cache')
const cmd_agg    = require('./command/aggregate')
const cmd_dump   = require('./command/dump')
const cmd_import = require('./command/import-db')

module.exports = (P, context) => {

gd.context = context

const conf        = gd.conf()
const conf_local  = gd.localConf ()
const conf_global = gd.globalConf()

P.command('pull').description('Git pull')
.action(() => cmd_pull(P.server))

P.command('clone')
.description('Git clone on remote server')
.action(() => require('./command/clone')(P.server))

P.command('deploy')
.description('Git clone / create db, settings & vhost (if not exist) / reload apache2 on remote server')
.action(() => {
  require('./command/clone')(P.server, () => {
    require('./command/create-db')(null, () => {
      require('./command/vhost')(null, () => {
        require('./command/settings')(null, () => {
          require('./command/composer')()
        })
      })
    })
  })
})

P.command('create-db')
.description('Create db (if not exist) on specified server')
.action(() => require('./command/create-db')(P.server))

P.command('vhost')
.description('Create vhost (if not exist) on remote server')
.action(() => require('./command/vhost')(P.server))

P.command('settings')
.description('Create settings.php (if not exist) on remote server')
.action(() => require('./command/settings')(P.server))

P.command('gulp')
.description('Run gulp from any folder')
.action(() => cmd_gulp(P.server, gd.getArg(P.args)))

P.command('asset')
.description('SCP css/js to remote server')
.action(() => cmd_asset(P.server))

P.command('update')
.alias('up')
.description('Run gulp / git pull / scp css&js / clear-cache on remote server')
.action(() => {
  cmd_gulp(P.server, 'build', () => {
    cmd_pull(null, () => {
      cmd_asset(null, () => {
        cmd_cc(null, () => {
          require('./command/composer')()
        })
      })
    })
  })
})

P.command('simple-update')
.alias('sup')
.description('git pull / clear-cache on specified server')
.action(() => {
  cmd_pull(P.server, () => {
    cmd_cc(null, () => {
      require('./command/composer')()
    })
  })
})

P.command('clear-cache')
.alias('cc')
.description('Drush clear-cache')
.action(() => cmd_cc(P.server))

P.command('agg')
.description('Change drupal css & js aggregation (default : turn off) set true to turn on')
.action(() => cmd_agg(P.server, gd.getArg(P.args)))

P.command('open').alias('o')
.description('Open website in default browser')
.action(() => require('./command/open')(P.server))

P.command('get-files').alias('gf')
.description('Get Project contributed files')
.action(() => require('./command/get-files')(P.server))

P.command('sync-files').alias('sf')
.description('Synchronize project contributed files')
.action(() => require('./command/sync-files')(P.server))

P.command('dump').alias('db')
.description('Get DB dump from remote server')
.action(() => cmd_dump(P.server))

P.command('get-db').alias('getdb')
.description('Shortcut for "dump" + "import-db"')
.action(() => {
  cmd_dump(P.server, () => {
    cmd_import(null, () => {
      cmd_agg('dev')
    })
  })
})

P.command('download').alias('dld')
.description('Shortcut for "dump" + "import-db" + "get-files" + "pull -s dev" + "disable aggregation css&js"')
.action(() => {
  cmd_pull('dev', () => {
    cmd_dump(P.server, () => {
      cmd_import(null, () => {
        cmd_agg('dev', false, () => {
          require('./command/get-files')(P.server)
        })
      })
    })
  })
})

P.command('composer')
.description('Composer install on specified server')
.action(() => require('./command/composer')(P.server, gd.getArg(P.args)))

P.command('wordpress').alias('wp')
.description('Wordpress update')
.action(() => require('./command/wordpress')(P.server, gd.getArg(P.args)))

P.command('wp-plugin')
.description('Install wordpress plugin')
.action(() => require('./command/wordpress-plugin')(P.server, gd.getArg(P.args)))


const conf_parameters = {
  'global': ['db_user', 'db_pass', 'token', 'username'],
  'local':  ['db_name', 'db_server_pass', 'url', 'branch'],
}

for(const conf_type in conf_parameters) {
  for(const bgi in conf_parameters[conf_type]) {
    const gb = conf_parameters[conf_type][bgi]

    P.command(gb).alias(gb.replace(/_/g, ''))
    .description(`Set ${conf_type} ${gb} or unset if nothing passed`)
    .action(() => {
      const arg = gd.getArg(P.args)

      let server = P.server ? P.server + '.' : '';

      if(conf_type === 'global'){
        arg ? conf_global.set(server + gb, arg) : conf_global.delete(server + gb)
      }
      else if(conf_type === 'local'){
        arg ? conf_local.set(server + gb, arg) : conf_local.delete(server + gb)
      }
    })
  }
}

P.command('conf').alias('config')
.description('Display current configuration')
.action(() => require('./command/config')(P.server))

P.command('conf-clear').alias('config-clear')
.description('Clear current configuration')
.action(() => {
  conf_local.clear()
  conf_global.clear()
})

P.command('init').alias('config-default')
.description('Generate default configuration')
.action(() => require('./command/init')())

P.command('plugin').description('Install plugin')
.action(() => {
  require('./command/plugin')(P.server, gd.getArg(P.args), () => {
    cmd_gulp(null, 'build')
  })
})

P.command('plugin-remove').description('Uninstall plugin')
.action(() => {
  require('./command/plugin-remove')(P.server, gd.getArg(P.args), () => {
    cmd_gulp(null, 'build')
  })
})

P.command('plugin-list').description('List available plugins')
.action(() => require('./command/plugin-list')())

P.command('gui').description('Add project to bitbar app')
.action(() => require('./command/gui')())

P.command('gui-remove').description('Remove project from bitbar app')
.action(() => require('./command/gui-remove')())

P.command('*').action(() => gd.error('Command not found. See "gd -h"\n'))

}
