<?php


/**
 * Sanitize File upload name
 * @param $filename
 * @return mixed|string
 */
function filter_sanitize_file_name($filename) {
// Force the file name in UTF-8 (encoding Windows / Mac / Linux)
  $filemane = mb_convert_encoding($filename, "UTF-8");

  $char_not_clean = array(
    '/@/',
    '/À/',
    '/Á/',
    '/Â/',
    '/Ã/',
    '/Ä/',
    '/Å/',
    '/Ç/',
    '/È/',
    '/É/',
    '/Ê/',
    '/Ë/',
    '/Ì/',
    '/Í/',
    '/Î/',
    '/Ï/',
    '/Ò/',
    '/ Ó/',
    '/Ô/',
    '/Õ/',
    '/Ö/',
    '/Ù/',
    '/Ú/',
    '/Û/',
    '/Ü/',
    '/Ý/',
    '/à/',
    '/á/',
    '/â/',
    '/ã/',
    '/ä/',
    '/å/',
    '/ç/',
    '/è/',
    '/é/',
    '/ ê/',
    '/ë/',
    '/ì/',
    '/í/',
    '/î/',
    '/ï/',
    '/ð/',
    '/ò/',
    '/ó/',
    '/ô/',
    '/õ/',
    '/ö/',
    '/ù/',
    '/ú/',
    '/û/',
    '/ü/',
    '/ý/',
    '/ÿ/',
    '/©/'
  );
  $clean = array(
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'a',
    'c',
    'e',
    'e',
    'e',
    'e',
    'i',
    'i',
    'i',
    'i',
    'o',
    'o',
    'o',
    'o',
    'o',
    'u',
    'u',
    'u',
    'u',
    'y',
    'a',
    'a',
    'a',
    'a ',
    'a',
    'a',
    'c',
    'e',
    'e',
    'e',
    'e',
    'i',
    'i',
    'i',
    'i',
    'o',
    'o',
    'o',
    'o',
    'o',
    'o',
    'u',
    'u',
    'u',
    'u',
    'y',
    'y',
    'copy'
  );
  $friendly_filename = preg_replace($char_not_clean, $clean, $filename);
  // After replacement, we destroy the last residues
  $friendly_filename = utf8_decode($friendly_filename);
  $friendly_filename = preg_replace('/\?/', '', $friendly_filename);
  // Lowercase
  $friendly_filename = strtolower($friendly_filename);
  return $friendly_filename;
}

add_filter('sanitize_file_name', 'filter_sanitize_file_name', 5);

/**
 * App Pagination
 * @param int $posts_per_page
 * @param null $query_object
 * @param bool $first_last
 * @param array $query_vars
 */
function app_pagination($posts_per_page = 10, $query_object = null, $first_last = false, $query_vars = array())
{
  global $wp_query;

  if(is_object($query_object)) {
    $max_num_pages = ceil(((int) $query_object->found_posts) / $posts_per_page);
  } else {
    $max_num_pages = $wp_query->max_num_pages;
  }

  $big = 999999999; // need an unlikely integer
  $pages = paginate_links(array(
    'base' => str_replace($big, '%#%', html_entity_decode(get_pagenum_link($big))),
    'format' => '?paged=%#%',
    'current' => max(1, current_page()),
    'total' => $max_num_pages,
    'type' => 'array',
    'prev_next' => true,
    'prev_text' => __('prev'),
    'next_text' => __('next'),
    'add_args' => $query_vars
  ));

  if (is_array($pages)) {
    $paged = (get_query_var('paged') == 0) ? 1 : get_query_var('paged');
    echo '<div class="gd-pagination text-center"><ul class="pagination">';

    if ($first_last && current_page() != 1) {
      echo '<li class="first-page"> <a href="' . get_pagenum_link(1) .'">First</a> </li>';
    }

    foreach ($pages as $page) {
      echo "<li>$page</li>";
    }

    if ($first_last && current_page() != $max_num_pages) {
      echo '<li class="last-page"> <a href="' . get_pagenum_link($max_num_pages) .'">Last</a> </li>';
    }

    echo '</ul></div>';
  }
}


/**
 * Current page number
 * @return int
 */
function current_page() {
  $page = ( get_query_var('page') ) ? get_query_var('page') : 1;
  $paged = ( get_query_var('paged') ) ? get_query_var('paged') : 1;

  if ($page == $paged) {
    return 1;
  } elseif ($page > $paged) {
    return $page;
  } else {
    return $paged;
  }
}


/**
 * Render template
 * @param $template_name
 * @param array $variables
 * @return string
 */
function render_template($template_name, $variables = array()) {

  ob_start();
  extract($variables);
  include(locate_template($template_name));
  $content = ob_get_contents();
  ob_end_clean();

  return $content;
}

/**
 * get_youtube_id
 * @param $url
 * @return bool|string
 */
function get_youtube_id($url) {
  // Find the ID of the video they want to play from the url.
  if (stristr($url, 'http://')) {
    $url = substr($url, 7);
  }
  elseif (stristr($url, 'https://')) {
    $url = substr($url, 8);
  }

  if (stristr($url, 'playlist')) {
    // Playlists need the appended ampersand to take the options properly.
    $url = $url . '&';
    $pos = strripos($url, '?list=');
    if ($pos !== FALSE) {
      $pos2 = stripos($url, '&');
      $pos2++;
    }
    else {
      return FALSE;
    }
  }
  // Alternate playlist link.
  elseif (stristr($url, 'view_play_list')) {
    $url = $url . '&';
    // All playlist ID's are prepended with PL.
    if (!stristr($url, '?p=PL')) {
      $url = substr_replace($url, 'PL', strpos($url, '?p=') + 3, 0);
    }
    // Replace the links format with the embed format.
    $url = str_ireplace('play_list?p=', 'videoseries?list=', $url);
    $pos = strripos($url, 'videoseries?list=');
    if ($pos !== FALSE) {
      $pos2 = stripos($url, '&');
      $pos2++;
    }
    else {
      return FALSE;
    }
  }
  else {
    $pos = strripos($url, 'v=');
    if ($pos !== FALSE) {
      $pos += 2;
      $pos2 = stripos($url, '&', $pos);
      $pos_hash = stripos($url, '#', $pos);

      $pos2 = video_embed_get_min($pos2, $pos_hash);
    }
    else {
      $pos = strripos($url, '/');
      if ($pos !== FALSE) {
        $pos++;
        $pos2 = stripos($url, '?', $pos);
        $pos_hash = stripos($url, '#', $pos);

        $pos2 = video_embed_get_min($pos2, $pos_hash);
      }
    }
  }
  if ($pos === FALSE) {
    return FALSE;
  }
  else {
    if ($pos2 > 0) {
      $id = substr($url, $pos, $pos2 - $pos);
    }
    else {
      $id = substr($url, $pos);
    }
  }
  return $id;
}

/**
 * video_embed_get_min
 * @param string $pos1
 *   The first index.
 * @param string $pos2
 *   The second index.
 *
 * @return string
 *   The min index.
 */
function video_embed_get_min($pos1, $pos2) {
  if (!$pos1) {
    return $pos2;
  }
  elseif (!$pos2) {
    return $pos1;
  }
  else {
    return min($pos1, $pos2);
  }
}
