const gd = require('../helper/gd.js')

const support = {}

support.type = require('../config/support.json');

support.isSupported = function(type) {

  if(!type || !support.type[type]) {
    gd.exit(`${type} is not currently supported.`)
  }
}

support.isCommandExcluded = function(command, printError) {

  const conf    = gd.conf()
  const type    = conf.config.type
  const version = conf.config.version

  support.isSupported(type);

  var exclude_list;

  if(support.type[type][version] && support.type[type][version]['exclude']){
    exclude_list = support.type[type][version]['exclude']
  }
  else if(support.type[type]['all'] && support.type[type]['all']['exclude']){
    exclude_list = support.type[type]['all']['exclude']
  }
  else {
    return false // no excluded command for this type/version
  }

  if(exclude_list.indexOf(command) > -1) {
    if(printError){
      gd.status(`'${command}' is not supported for ${type} ${version}`);
    }
    return true
  }

  return false
}

support.getRoot = function(conf) {

  const type    = conf.config.type
  const version = conf.config.version

  support.isSupported(type);

  if(conf.config['root']) {
    return conf.config['root']
  }
  if(support.type[type][version] && support.type[type][version]['root_folder']){
    return support.type[type][version]['root_folder']
  }
  if(support.type[type]['all'] && support.type[type]['all']['root_folder']){
    return support.type[type]['all']['root_folder']
  }
  return support.type['default']['root_folder']
}

support.findRoot = function(conf, cwd) {

  const type    = conf.config.type
  const version = conf.config.version

  cwd = cwd || null

  const site_local = require('find-up').sync('.git', {'cwd':cwd});
  if(!site_local) {
    gd.exit("can't find .git, the project must be a git repository")
  }

  // special case for gd_theme mode DEV
  if(/\/gd_theme\/\.git/.test(site_local)) {
    return site_local.replace('.git', '');
  }

  let root = support.getRoot(conf);

  // Special case for D7 (can be www or web)
  if(type === 'drupal' && version === '7.x') {
    var d7_path = site_local.replace('.git', 'www');
    if(require('is-there')(d7_path)){
      return d7_path;
    }
  }

  if(root === './'){
    root = ''
  }

  return site_local.replace('.git', root);
}


support.getProjectDirs = function(conf) {
  conf = conf || gd.conf()
  const type    = conf.config.type
  const version = conf.config.version

  switch(type) {
    case 'drupal': return [{
        src : '/sites/default/files',
        dest: '/sites/default'
    }];
    case 'symfony': return [{
        src : 'uploads/',
        dest: 'web/'
    }];
    case 'wordpress': return [{
        src : '/' + conf.config['wp-content'] + '/uploads',
        dest: '/' + conf.config['wp-content']
    }];
    case 'prestashop': return [{
      src : '/img',
      dest: ''
    },{
      src : '/download',
      dest: ''
    },{
      src : '/upload',
      dest: ''
    }];
    default: return [];
  }
}

module.exports = support
